abacusai.chat_message — AbacusAI documentation

# `abacusai.chat_message`

## Module Contents

### Classes

`ChatMessage` | A single chat message with Abacus Chat.

class abacusai.chat_message.ChatMessage(client, role=None, text=None, timestamp=None, isUseful=None, feedback=None, docIds=None, hotkeyTitle=None, tasks=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A single chat message with Abacus Chat.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - role (str) – The role of the message sender

    - text (list[dict]) – A list of text segments for the message

    - timestamp (str) – The timestamp at which the message was sent

    - isUseful (bool) – Whether this message was marked as useful or not

    - feedback (str) – The feedback provided for the message

    - docIds (list[str]) – A list of IDs of the uploaded document if the message has

    - hotkeyTitle (str) – The title of the hotkey prompt if the message has one

    - tasks (list[str]) – The list of spawned tasks, if the message was broken down into smaller sub-tasks.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict